pub enum RouteSegment {
UseBy {
moniker: Moniker,
capability: String,
source: String,
},
OfferBy {
moniker: Moniker,
capability: String,
source: String,
target: String,
},
ExposeBy {
moniker: Moniker,
capability: String,
source: String,
target: String,
},
DeclareBy {
moniker: Moniker,
capability: String,
},
}Variants
UseBy
The capability was used by a component instance in its manifest.
Fields
OfferBy
The capability was offered by a component instance in its manifest.
Fields
ExposeBy
The capability was exposed by a component instance in its manifest.
Fields
DeclareBy
The capability was declared by a component instance in its manifest.